@@ -14,14 +14,20 @@ def resource_path(relative_path: str) -> str:
     """ Get absolute path to resource required for PyInstaller """
     # noinspection SpellCheckingInspection
     base_path = getattr(sys, '_MEIPASS', os.path.dirname(os.path.abspath(__file__)))
-    return os.path.join(base_path, relative_path)
+    path = os.path.join(base_path, relative_path)
+    if not os.path.exists(path):
+        raise FileNotFoundError(f'File {path} does not exist')
+    return path
 
 
 def plugin_resource_path(relative_path: str) -> str:
     """ Get absolute path to resource required for PyInstaller """
     # noinspection SpellCheckingInspection
-    base_path = getattr(sys, '_MEIPASS', os.path.dirname(os.path.abspath(sys.argv[0])))
-    return os.path.join(base_path, relative_path)
+    base_path = getattr(sys, '_MEIPASS', os.path.dirname(os.path.abspath(__file__)))
+    path = os.path.join(base_path, '../..', relative_path)
+    if not os.path.exists(path):
+        raise FileNotFoundError(f'File {path} does not exist')
+    return path
 
 
 def get_bitmap_from_svg(bitmap_name) -> wx.Bitmap:
