@@ -1,6 +1,7 @@
 from typing import List, Tuple, Optional, Union
 
 import wx
+import wx.adv
 import wx.lib.masked.numctrl
 import wx.svg
 
@@ -12,6 +13,7 @@ from asn1editor.view.AbstractViewFactory import AbstractViewFactory
 from asn1editor.wxPython import Resources
 from asn1editor.wxPython.Styler import Styler
 from asn1editor.wxPython.WxPythonComplexViews import WxPythonContainerView, WxPythonListView, WxPythonChoiceView
+from asn1editor.wxPython.WxPythonDateTimeViews import WxPythonDateView, WxPythonTimeView, WxPythonDateTimeView
 from asn1editor.wxPython.WxPythonViews import WxPythonValueView, WxPythonBooleanView, \
     WxPythonBitstringView, WxPythonHexStringView, WxPythonValueSelectionView, ControlList
 
@@ -166,6 +168,34 @@ class WxPythonViewFactory(AbstractViewFactory):
 
         return view, view, view if optional else None
 
+    def get_date_view(self, name: str, optional: bool) -> Tuple[AbstractView, ValueInterface, OptionalInterface]:
+        controls = self._get_controls(name, optional, ':', 'date')
+
+        controls['value'] = wx.adv.DatePickerCtrl(self._window)
+        self._apply_style(controls)
+
+        view = WxPythonDateView(name, controls)
+        return view, view, view if optional else None
+
+    def get_time_view(self, name: str, optional: bool) -> Tuple[AbstractView, ValueInterface, OptionalInterface]:
+        controls = self._get_controls(name, optional, ':', 'date')
+
+        controls['value'] = wx.adv.TimePickerCtrl(self._window)
+        self._apply_style(controls)
+
+        view = WxPythonTimeView(name, controls)
+        return view, view, view if optional else None
+
+    def get_datetime_view(self, name: str, optional: bool) -> Tuple[AbstractView, ValueInterface, OptionalInterface]:
+        controls = self._get_controls(name, optional, ':', 'date')
+
+        controls['value'] = wx.adv.DatePickerCtrl(self._window)
+        controls['time'] = wx.adv.TimePickerCtrl(self._window)
+        self._apply_style(controls)
+
+        view = WxPythonDateTimeView(name, controls)
+        return view, view, view if optional else None
+
     def _get_controls(self, name: str, optional: bool, suffix: str = '', icon: str = None, icon_tooltip: str = None) -> \
             ControlList:
         controls = {}
