@@ -2,6 +2,7 @@ import typing
 from typing import Optional, Callable, List, Tuple
 
 import wx
+import wx.adv
 
 from asn1editor.interfaces.BitstringInterface import BitstringInterface
 from asn1editor.interfaces.OptionalInterface import OptionalInterface
@@ -9,7 +10,7 @@ from asn1editor.interfaces.ValueInterface import ValueInterface
 from asn1editor.view.AbstractView import AbstractView
 
 ControlList = typing.Dict[str, typing.Union[wx.TextCtrl, wx.CheckBox, wx.StaticBitmap, wx.ComboBox, wx.StaticText, wx.SpinCtrl, List[Tuple[int, wx.CheckBox]],
-                                            str]]
+                                            str, wx.adv.DatePickerCtrl, wx.adv.TimePickerCtrl]]
 
 
 class WxPythonView(AbstractView, OptionalInterface):
@@ -74,12 +75,12 @@ class WxPythonView(AbstractView, OptionalInterface):
         sizer = wx.BoxSizer(orientation)
         if orientation == wx.HORIZONTAL:
             if 'icon' in self._controls:
-                sizer.Add(self._controls['icon'], flag=wx.ALL | wx.ALIGN_CENTER_VERTICAL)
+                sizer.Add(self._controls['icon'], flag=wx.ALL | wx.ALIGN_CENTER_VERTICAL, border=2)
             sizer.Add(self._controls['name'], flag=wx.ALL | wx.ALIGN_CENTER_VERTICAL, border=5)
         else:
             if 'icon' in self._controls:
                 sub_sizer = wx.BoxSizer(wx.HORIZONTAL)
-                sub_sizer.Add(self._controls['icon'], flag=wx.ALL | wx.ALIGN_CENTER_VERTICAL)
+                sub_sizer.Add(self._controls['icon'], flag=wx.ALL | wx.ALIGN_CENTER_VERTICAL, border=2)
                 sub_sizer.Add(self._controls['name'], flag=wx.ALL | wx.ALIGN_CENTER_VERTICAL, border=5)
                 sizer.Add(sub_sizer)
             else:
@@ -130,32 +131,16 @@ class WxPythonValueView(WxPythonView, ValueInterface):
             self._controls['value'].SetToolTip('\n'.join([self.get_value(), previous_tooltip]))
 
 
-class WxPythonValueSelectionView(WxPythonView, ValueInterface):
+class WxPythonValueSelectionView(WxPythonValueView):
     def __init__(self, name: str, controls: ControlList):
         super(WxPythonValueSelectionView, self).__init__(name, controls)
 
-    def get_sizer(self, recursive: bool) -> wx.Sizer:
-        sizer = self._create_sizer()
-        sizer.Add(self._controls['value'], flag=wx.ALL | wx.EXPAND, border=5)
-        return sizer
-
-    def register_change_event(self, callback: Callable):
-        # noinspection PyUnusedLocal
-        def event_closure(e: wx.Event):
-            del e
-            callback()
-
-        self._controls['value'].Bind(wx.EVT_TEXT, event_closure)
-
     def get_value(self) -> str:
         return self._controls['value'].GetStringSelection()
 
     def set_value(self, val: str):
         self._controls['value'].SetStringSelection(val)
 
-    def enable(self, enabled: bool):
-        self._controls['value'].Enable(enabled)
-
 
 class WxPythonHexStringView(WxPythonView, ValueInterface):
     CHARS_PER_HEX_DIGIT = 3
@@ -306,7 +291,11 @@ class WxPythonBitstringView(WxPythonView, BitstringInterface):
 
     def get_sizer(self, recursive: bool) -> wx.Sizer:
         sizer = self._create_sizer()
-        bits_sizer = wx.StaticBoxSizer(wx.VERTICAL, self._parent, "Bits")
+        if self._controls['name'].IsShown():
+            bits_sizer = wx.StaticBoxSizer(wx.VERTICAL, self._parent, "Bits")
+        else:
+            bits_sizer = wx.BoxSizer(wx.VERTICAL)
+
         for _, checkbox in self._controls['checkboxes']:
             bits_sizer.Add(checkbox)
         sizer.Add(bits_sizer)
